UnCodeGL
=========

The UnCodeGL library for python is an easy to use tool for Coding Theory. 
It implements the basics metrics and algorithms from sources and codes. 

To install the library use :
    
    pip install UnCodeGL

To read the documentation please refer to [the documentation](https://uncodegl.readthedocs.io/en/latest/)